@@ -26,7 +26,7 @@ use Encode 'encode_utf8';
 
 use experimental 'postderef';
 
-our $VERSION = "v0.0.11";
+our $VERSION = "v0.0.12";
 
 use constant {
     DEFAULT_HEARTBEAT_INTERVAL        => 5,
@@ -195,11 +195,11 @@ sub register ($self, $app, $config) {
         });
     });
 
-    $app->helper("$bs_prefix.add_action", sub ($c, $channel_name, $action_name, $action_sub) {
+    $app->helper("$bs_prefix.on_action", sub ($c, $channel_name, $action_name, $action_sub) {
         BoardStreams::Registry->add_action($channel_name, $action_name, $action_sub);
     });
 
-    $app->helper("$bs_prefix.add_request", sub ($c, $channel_name, $request_name, $request_sub) {
+    $app->helper("$bs_prefix.on_request", sub ($c, $channel_name, $request_name, $request_sub) {
         BoardStreams::Registry->add_request($channel_name, $request_name, $request_sub);
     });
 
@@ -506,6 +506,7 @@ sub register ($self, $app, $config) {
 
                 # join handler
                 my $join_handler = BoardStreams::Registry->get_join($channel_name) or return;
+                $c->$bs_prefix->channel_exists($channel_name) or return;
                 my $attrs = { since_id => $since_id, is_reconnect => int(defined $since_id) };
                 my $join_ret = eval { $join_handler->($channel_name, $c, $attrs) };
                 if ($join_ret->$_can('then')) {
@@ -660,10 +661,12 @@ sub register ($self, $app, $config) {
 
     $app->helper("$bs_prefix.get_state", sub ($c, $channel_name) {
         my $db = $c->$bs_prefix->db;
-        my $state = from_json $db->select('channel',
+        my $hash = $db->select('channel',
             ['state'],
             { name => $channel_name },
-        )->hash->{state};
+        )->hash;
+
+        return $hash ? from_json($hash->{state}) : undef;
     });
 
     $app->helper("$bs_prefix.alive_workers", sub ($c) {
@@ -804,6 +807,11 @@ sub register ($self, $app, $config) {
         );
     });
 
+    $app->helper("$bs_prefix.channel_exists", sub ($c, $channel_name) {
+        my $hash = $c->$bs_prefix->db->select('channel', 'id', { name => $channel_name })->hash;
+        return !! $hash;
+    });
+
     # system channels
     {
         $app->$bs_prefix->create_channel($WORKERS_CHANNEL, {});
